@@ -48,7 +48,7 @@ var PolicyState = {
         !(uri.schemeIs("http") || uri.schemeIs("https")))
       return;
 
-    let hints = this.hintsForURI(uri, true);
+    let hints = this.hintsForURI(uri, true) || uri !== channel.originalURI && this.hintsForURI(channel.originalURI, true);
     if (hints) {
       hints._attached = true;
       if (hints.contentType === 6) {
@@ -163,7 +163,7 @@ PolicyHints.prototype = (function() {
    return proto;
 })();
 
-const NOPContentPolicy = {
+var NOPContentPolicy = {
   shouldLoad: CP_NOP,
   shouldProcess: CP_NOP
 };
@@ -193,7 +193,7 @@ const NOPContentPolicy = {
 // ACCEPT = 1
 
 
-const MainContentPolicy = {
+var MainContentPolicy = {
   shouldLoad: function(aContentType, aContentLocation, aRequestOrigin, aContext, aMimeTypeGuess, aInternalCall, principal) {
     if (!aContentLocation) {
       if (aContentType === 5 && aInternalCall === CP_SHOULDPROCESS && aMimeTypeGuess === "application/x-shockwave-flash")
@@ -656,7 +656,7 @@ const MainContentPolicy = {
         let scriptElement;
         if (aContentType === 2) { // "real" JavaScript include
           if (!(this.cascadePermissions || this.globalHttpsWhitelist) &&
-              originSite && !this.isJSEnabled(originSite, contentDocument.window) &&
+              originSite && !this.isJSEnabled(originSite, contentDocument && contentDocument.window) &&
               isHTTP && httpOrigin) {
             // JavaScript-disabled page with script inclusion
             this.syncUI(contentDocument);
@@ -691,7 +691,7 @@ const MainContentPolicy = {
         } else isScript = scriptElement = false;
 
         if (forbid) {
-          let doc = aContext.ownerDocument || aContext;
+          let doc = aContext && aContext.ownerDocument || aContext;
           let win = doc && doc.defaultView;
           forbid = !this.isJSEnabled(locationSite, win);
           if (forbid && this.ignorePorts && /:\d+$/.test(locationSite))
@@ -799,17 +799,13 @@ const MainContentPolicy = {
           ? this.isJSEnabled(originSite, win)
           : jsRx.test(originURL); // if we've got such an origin, parent should be trusted
 
+        if (locationSite && this.checkShorthands(locationSite)) this.autoTemp(locationSite);
+
         let locationOK = locationSite
               ? this.isJSEnabled(locationSite, win)
               : jsRx.test(locationURL) && originOK // use origin for javascript: or data:
         ;
 
-        if (!locationOK && locationSite && this.ignorePorts && this.portRx.test(locationSite)) {
-          if (this.isJSEnabled(locationSite.replace(this.portRx, ''))) {
-            locationOK = this.autoTemp(locationSite);
-          }
-        }
-
         forbid = !(locationOK && (originOK ||
           !this.getPref(blockThisFrame
             ? "forbidIFramesParentTrustCheck" : "forbidActiveContentParentTrustCheck",
@@ -890,7 +886,7 @@ const MainContentPolicy = {
 
       if (!aInternalCall) PolicyState.removeCheck(aContentLocation);
 
-      if (isHTTP) PolicyState.save(unwrappedLocation, arguments);
+      if (isHTTP) PolicyState.save(aContentLocation, arguments);
 
     }
     return CP_OK;
